@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timedelta
 from functools import reduce
 
 import pytest
@@ -180,6 +180,65 @@ def test_batch_timeframe_includes_with_wrong_type_raises_error():
         btf.includes([1, 1.0, "dummy"])
 
 
+def test_batch_timeframe_inclusion_check_with_in_keyword(faker, empty_timeframe):
+    dt1 = faker.date_time_between(start_date="-1y", end_date="-6M")
+    dt2 = faker.date_time_between(start_date="-5M", end_date="now")
+
+    dt12 = faker.date_time_between(start_date=dt1, end_date=dt2)
+
+    dt3 = dt1 + timedelta(days=1)
+    dt4 = dt2 - timedelta(days=1)
+
+    dt5 = faker.date_time_between(start_date="now", end_date="+1y")
+    dt6 = faker.date_time_between(start_date="+2y")
+
+    tf1 = TimeFrame(dt1, dt2)
+    tf2 = TimeFrame(dt3, dt4)
+    tf3 = TimeFrame(dt5, dt6)
+
+    assert tf2 in BatchTimeFrame([tf1])
+    assert tf1 in BatchTimeFrame([tf1])
+    assert BatchTimeFrame([tf1]) in BatchTimeFrame([tf1])
+    assert tf3 not in BatchTimeFrame([tf1])
+    assert dt12 in BatchTimeFrame([tf1])
+    assert dt5 not in BatchTimeFrame([tf1])
+    assert tf1.start in BatchTimeFrame([tf1])
+    assert tf1.end in BatchTimeFrame([tf1])
+    assert empty_timeframe in BatchTimeFrame([tf1])
+
+
+def test_batch_timeframe_inclusion_check_with_other_types_raise_value_error(faker):
+    dt1 = faker.date_time_between(start_date="-1y", end_date="-6M")
+    dt2 = faker.date_time_between(start_date=dt1, end_date="now")
+
+    with pytest.raises(TypeError):
+        faker.pyint() in BatchTimeFrame([TimeFrame(dt1, dt2)])
+
+    with pytest.raises(TypeError):
+        faker.pyfloat() in BatchTimeFrame([TimeFrame(dt1, dt2)])
+
+    with pytest.raises(TypeError):
+        faker.text() in BatchTimeFrame([TimeFrame(dt1, dt2)])
+
+    with pytest.raises(TypeError):
+        [] in BatchTimeFrame([TimeFrame(dt1, dt2)])
+
+    with pytest.raises(TypeError):
+        [faker.pyint(), faker.pyfloat(), faker.text()] in BatchTimeFrame(
+            [TimeFrame(dt1, dt2)]
+        )
+
+    with pytest.raises(TypeError):
+        faker.pybool() in BatchTimeFrame([TimeFrame(dt1, dt2)])
+
+
+def test_batch_timeframe_inclusion_check_with_include_warns_deprecation(
+    random_timeframe, random_batch_timeframes
+):
+    with pytest.warns(DeprecationWarning):
+        random_batch_timeframes.includes(random_timeframe)
+
+
 # ======================= Summation ============================
 def test_batch_timeframe_add_two_instances_successfully():
     tf1 = TimeFrame(datetime(2021, 1, 18, 10), datetime(2021, 1, 18, 11))
@@ -364,8 +423,8 @@ def test_batch_timeframe_multiply_with_non_base_timeframe_raises_type_error():
         btf * [1, 1.0, "dummy", True]
 
 
-# ======================= Substraction ============================
-def test_batch_timeframe_substract_two_instances_successfully():
+# ======================= Subtraction ============================
+def test_batch_timeframe_subtract_two_instances_successfully():
     tf1 = TimeFrame(datetime(2021, 1, 18, 10), datetime(2021, 1, 18, 11))
     tf2 = TimeFrame(datetime(2021, 1, 18, 12), datetime(2021, 1, 18, 14))
     tf3 = TimeFrame(datetime(2021, 1, 18, 18), datetime(2021, 1, 18, 20))
@@ -386,7 +445,7 @@ def test_batch_timeframe_substract_two_instances_successfully():
     assert btf2.duration == btf1.duration
 
 
-def test_batch_timeframe_substract_with_timeframe_successfully():
+def test_batch_timeframe_subtract_with_timeframe_successfully():
     tf1 = TimeFrame(datetime(2021, 1, 18, 10), datetime(2021, 1, 18, 11))
     tf2 = TimeFrame(datetime(2021, 1, 18, 12), datetime(2021, 1, 18, 14))
     tf3 = TimeFrame(datetime(2021, 1, 18, 18), datetime(2021, 1, 18, 20))
@@ -408,7 +467,7 @@ def test_batch_timeframe_substract_with_timeframe_successfully():
     assert btf2.duration == (tf1 + tf2 + tf3 - tf5).duration
 
 
-def test_batch_timeframe_substract_from_empty_timeframe_results_in_the_same_object():
+def test_batch_timeframe_subtract_from_empty_timeframe_results_in_the_same_object():
     tf1 = TimeFrame(datetime(2021, 1, 18, 10), datetime(2021, 1, 18, 11))
     tf2 = TimeFrame(datetime(2021, 1, 18, 12), datetime(2021, 1, 18, 14))
     tf3 = TimeFrame(datetime(2021, 1, 18, 18), datetime(2021, 1, 18, 20))
@@ -430,7 +489,7 @@ def test_batch_timeframe_substract_from_empty_timeframe_results_in_the_same_obje
     assert btf2.duration == btf1.duration
 
 
-def test_batch_timeframe_substract_from_non_base_timeframe_raises_type_error():
+def test_batch_timeframe_subtract_from_non_base_timeframe_raises_type_error():
     tf1 = TimeFrame(datetime(2021, 1, 17, 10), datetime(2021, 1, 17, 11))
     tf2 = TimeFrame(datetime(2021, 1, 17, 12), datetime(2021, 1, 17, 14))
     tf3 = TimeFrame(datetime(2021, 1, 17, 18), datetime(2021, 1, 17, 20))
@@ -523,8 +582,9 @@ def test_batch_timeframe_multiple_timeframes_repr():
         ]
     )
 
-    assert repr(
-        btf
-    ) == "2022-10-18T10:00:00#2022-10-18T11:00:00,2022-10-18T12:00:00#2022-10-18T14:00:00,2022-10-18T18:00:00#2022-10-18T20:00:00".replace(
-        ",", "\n"
+    assert (
+        repr(btf)
+        == "2022-10-18T10:00:00#2022-10-18T11:00:00,2022-10-18T12:00:00#2022-10-18T14:00:00,2022-10-18T18:00:00#2022-10-18T20:00:00".replace(
+            ",", "\n"
+        )
     )
